@@ -1,4 +1,4 @@
-#![feature(doc_cfg)]
+#![no_std]
 
 //! Floating point conversion functions.
 //!
@@ -30,9 +30,9 @@
 //!
 //! This crate is usable, but still incomplete:
 //!
-//! - There's no support for `f32` yet.
 //! - There's no support for converting *to* integers yet.
 //! - Native conversions are only available on ARM (32- and 64-bit) and x86 (32- and 64-bit).
+//! - The `f32` conversions do not yet use any native floating point instructions.
 //! - The truncating functions do not (yet) use any native floating point instructions.
 //! - More benchmarking still needs to happen.
 
